import { CfnTLSInspectionConfiguration } from 'aws-cdk-lib/aws-networkfirewall';
import * as core from 'aws-cdk-lib/core';
import { Construct } from 'constructs';
/**
 * Defines a TLS Inspection Configuration Resource in the stack
 */
export interface ITLSInspectionConfiguration extends core.IResource {
    /**
     * The Arn of the TLS Inspection Configuration.
     * @attribute
     */
    readonly tlsInspectionConfigurationArn: string;
    /**
     * The name of the TLS Inspection Configuration.
     * @attribute
     */
    readonly tlsInspectionConfigurationId: string;
}
/**
 * Defines a Network Firewall TLS Inspection Configuration
 */
declare abstract class TLSInspectionConfigurationBase extends core.Resource implements ITLSInspectionConfiguration {
    abstract readonly tlsInspectionConfigurationArn: string;
    abstract readonly tlsInspectionConfigurationId: string;
}
/**
 * The Properties for defining a Firewall TLS Inspection Configuration
 */
export interface TLSInspectionConfigurationProps {
    /**
     * The descriptive name of the TLS inspection configuration.
     * You can't change the name of a TLS inspection configuration after you create it.
     * @default - CloudFormation-generated name
     */
    readonly configurationName?: string;
    /**
     * The TLS Server Certificate Configuration Property
     */
    readonly serverCertificateConfigurations: CfnTLSInspectionConfiguration.ServerCertificateConfigurationProperty[];
    /**
     * The Description of the TLS Inspection Configuration
     * @default - No Description
     */
    readonly description?: string;
    /**
     * Tags to be added to the configuration.
     * @default - No tags applied
     */
    readonly tags?: core.Tag[];
}
/**
 * Defines a Network Firewall TLS Inspection Configuration in the Stack
 * @resource AWS::NetworkFirewall::TLSInspectionConfiguration
 */
export declare class TLSInspectionConfiguration extends TLSInspectionConfigurationBase {
    /**
     * Reference an existing TLS Inspection Configuration,
     * defined outside of the CDK code, by name.
     * @param scope
     * @param id
     * @param TLSInspectionConfigurationName
     */
    static fromConfigurationName(scope: Construct, id: string, TLSInspectionConfigurationName: string): ITLSInspectionConfiguration;
    /**
     * Reference an existing TLS Inspection Configuration,
     * defined outside of the CDK code, by arn.
     * @param scope
     * @param id
     * @param configurationArn
     */
    static fromConfigurationArn(scope: Construct, id: string, configurationArn: string): ITLSInspectionConfiguration;
    /**
     * The Arn of the TLS Inspection Configuration.
     * @attribute
     */
    readonly tlsInspectionConfigurationArn: string;
    /**
     * The physical name of the TLS Inspection Configuration.
     * @attribute
     */
    readonly tlsInspectionConfigurationId: string;
    /**
     * The Description of the TLS Inspection Configuration
     */
    readonly description?: string;
    /**
     * Tags to be added to the TLS Inspection Configuration.
     */
    readonly tags?: core.Tag[];
    /**
     *
     * @param scope
     * @param id
     * @param props
     */
    constructor(scope: Construct, id: string, props: TLSInspectionConfigurationProps);
}
export {};
